This is the core Asphalt library. If you're looking for documentation for some specific component
project, you will the appropriate link from the project's `Github page`_.

If you're a new user, it's a good idea to start from the tutorials. Pick a tutorial that suits
your current level of knowledge.

.. _Github page: https://github.com/asphalt-framework

Table of contents
-----------------

.. toctree::
   :maxdepth: 2

   tutorials/index
   userguide/index
   versionhistory
   acknowledgements

* :ref:`API reference <modindex>`
